==> jc-1.4.0.tar.gz: javax/swing/filechooser/FileView.h <==
// public abstract class javax.swing.filechooser.FileView

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 53f1aed411870362 javax_swing_filechooser_FileView

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_filechooser_FileView_H_
#define _JC_javax_swing_filechooser_FileView_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Boolean$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_Icon$object;

// Typedefs
typedef struct _jc_javax_swing_filechooser_FileView$sub_refs	_jc_javax_swing_filechooser_FileView$sub_refs;
typedef struct _jc_javax_swing_filechooser_FileView$sub_nonrefs	_jc_javax_swing_filechooser_FileView$sub_nonrefs;
typedef struct _jc_javax_swing_filechooser_FileView$refs	_jc_javax_swing_filechooser_FileView$refs;
typedef struct _jc_javax_swing_filechooser_FileView$nonrefs	_jc_javax_swing_filechooser_FileView$nonrefs;
typedef struct _jc_javax_swing_filechooser_FileView$object	_jc_javax_swing_filechooser_FileView$object;

typedef const struct _jc_javax_swing_filechooser_FileView$vmethods	_jc_javax_swing_filechooser_FileView$vmethods;
typedef const struct _jc_javax_swing_filechooser_FileView$vtable	_jc_javax_swing_filechooser_FileView$vtable;
typedef const struct _jc_javax_swing_filechooser_FileView$vtype	_jc_javax_swing_filechooser_FileView$vtype;

// Constructors
extern void _jc_javax_swing_filechooser_FileView$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_filechooser_FileView$method$getDescription$972a17752e6d478d(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *);
extern struct _jc_object *_jc_javax_swing_filechooser_FileView$method$getIcon$c755e65eb4359221(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_filechooser_FileView$method$getName$9dee978f517cb767(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_filechooser_FileView$method$getTypeDescription$07773f5d7253261f(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *);
extern struct _jc_java_lang_Boolean$object *_jc_javax_swing_filechooser_FileView$method$isTraversable$f1160e329f384a94(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_filechooser_FileView$method_info$getDescription$972a17752e6d478d;
extern _jc_method _jc_javax_swing_filechooser_FileView$method_info$getIcon$c755e65eb4359221;
extern _jc_method _jc_javax_swing_filechooser_FileView$method_info$getName$9dee978f517cb767;
extern _jc_method _jc_javax_swing_filechooser_FileView$method_info$getTypeDescription$07773f5d7253261f;
extern _jc_method _jc_javax_swing_filechooser_FileView$method_info$isTraversable$f1160e329f384a94;

// Virtual methods structure
struct _jc_javax_swing_filechooser_FileView$vmethods {
	struct _jc_java_lang_String$object	*(*getDescription$972a17752e6d478d)(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *);
	struct _jc_object	*(*getIcon$c755e65eb4359221)(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *);
	struct _jc_java_lang_String$object	*(*getName$9dee978f517cb767)(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *);
	struct _jc_java_lang_String$object	*(*getTypeDescription$07773f5d7253261f)(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *);
	struct _jc_java_lang_Boolean$object	*(*isTraversable$f1160e329f384a94)(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *);
};

// Vtable
struct _jc_javax_swing_filechooser_FileView$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_filechooser_FileView$vmethods	javax_swing_filechooser_FileView;
};

// Vtype
struct _jc_javax_swing_filechooser_FileView$vtype {
	_jc_type			type;
	_jc_javax_swing_filechooser_FileView$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_filechooser_FileView$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_filechooser_FileView$refs {
    _jc_javax_swing_filechooser_FileView$sub_refs	javax_swing_filechooser_FileView;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_filechooser_FileView$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_filechooser_FileView$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_filechooser_FileView$sub_nonrefs	javax_swing_filechooser_FileView;
};

// Object instance structure
struct _jc_javax_swing_filechooser_FileView$object {
	_jc_javax_swing_filechooser_FileView$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_filechooser_FileView$vtype	*vtype;
	_jc_javax_swing_filechooser_FileView$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_filechooser_FileView$vtype _jc_javax_swing_filechooser_FileView$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_filechooser_FileView, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_filechooser_FileView$class_object;

#endif	/* _JC_javax_swing_filechooser_FileView_H_ */

==> jc-1.4.6.tar.gz: javax/swing/filechooser/FileView.h <==
// public abstract class javax.swing.filechooser.FileView

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 53f1aed411870362 javax_swing_filechooser_FileView

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_filechooser_FileView_H_
#define _JC_javax_swing_filechooser_FileView_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Boolean$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_Icon$object;

// Typedefs
typedef struct _jc_javax_swing_filechooser_FileView$sub_refs	_jc_javax_swing_filechooser_FileView$sub_refs;
typedef struct _jc_javax_swing_filechooser_FileView$sub_nonrefs	_jc_javax_swing_filechooser_FileView$sub_nonrefs;
typedef struct _jc_javax_swing_filechooser_FileView$refs	_jc_javax_swing_filechooser_FileView$refs;
typedef struct _jc_javax_swing_filechooser_FileView$nonrefs	_jc_javax_swing_filechooser_FileView$nonrefs;
typedef struct _jc_javax_swing_filechooser_FileView$object	_jc_javax_swing_filechooser_FileView$object;

typedef const struct _jc_javax_swing_filechooser_FileView$vmethods	_jc_javax_swing_filechooser_FileView$vmethods;
typedef const struct _jc_javax_swing_filechooser_FileView$vtable	_jc_javax_swing_filechooser_FileView$vtable;
typedef const struct _jc_javax_swing_filechooser_FileView$vtype	_jc_javax_swing_filechooser_FileView$vtype;

// Constructors
extern void _jc_javax_swing_filechooser_FileView$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_filechooser_FileView$method$getDescription$972a17752e6d478d(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_filechooser_FileView$method$getIcon$c755e65eb4359221(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_filechooser_FileView$method$getName$9dee978f517cb767(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_filechooser_FileView$method$getTypeDescription$07773f5d7253261f(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Boolean$object *_jc_javax_swing_filechooser_FileView$method$isTraversable$f1160e329f384a94(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_filechooser_FileView$method_info$getDescription$972a17752e6d478d;
extern _jc_method _jc_javax_swing_filechooser_FileView$method_info$getIcon$c755e65eb4359221;
extern _jc_method _jc_javax_swing_filechooser_FileView$method_info$getName$9dee978f517cb767;
extern _jc_method _jc_javax_swing_filechooser_FileView$method_info$getTypeDescription$07773f5d7253261f;
extern _jc_method _jc_javax_swing_filechooser_FileView$method_info$isTraversable$f1160e329f384a94;

// Virtual methods structure
struct _jc_javax_swing_filechooser_FileView$vmethods {
	struct _jc_java_lang_String$object	*(*getDescription$972a17752e6d478d)(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getIcon$c755e65eb4359221)(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$9dee978f517cb767)(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getTypeDescription$07773f5d7253261f)(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Boolean$object	*(*isTraversable$f1160e329f384a94)(_jc_env *, struct _jc_javax_swing_filechooser_FileView$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_filechooser_FileView$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_filechooser_FileView$vmethods	javax_swing_filechooser_FileView;
};

// Vtype
struct _jc_javax_swing_filechooser_FileView$vtype {
	_jc_type			type;
	_jc_javax_swing_filechooser_FileView$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_filechooser_FileView$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_filechooser_FileView$refs {
    _jc_javax_swing_filechooser_FileView$sub_refs	javax_swing_filechooser_FileView;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_filechooser_FileView$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_filechooser_FileView$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_filechooser_FileView$sub_nonrefs	javax_swing_filechooser_FileView;
};

// Object instance structure
struct _jc_javax_swing_filechooser_FileView$object {
	_jc_javax_swing_filechooser_FileView$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_filechooser_FileView$vtype	*vtype;
	_jc_javax_swing_filechooser_FileView$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_filechooser_FileView$vtype _jc_javax_swing_filechooser_FileView$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_filechooser_FileView, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_filechooser_FileView$class_object;

#endif	/* _JC_javax_swing_filechooser_FileView_H_ */
